@@ -20,7 +20,9 @@
  */
 
 #ifndef __SABER__
+#ifndef LINT
 static char *Copyright= "Copyright 1989, 1993 Jim Frost";
+#endif /* LINT */
 #endif
 #define _JIM_COPYRIGHT_
 #endif
