@@ -22,7 +22,9 @@
 ****/
 
 #ifndef __SABER__
+#ifndef LINT
 static char *TGNCopyright = "Copyright (C) 1991 Tim Northrup";
+#endif /* LINT */
 #endif
 #define _TGN_COPYRIGHT_
 #endif
